@@ -278,12 +278,13 @@ static int jack_callback (jack_nframes_t nframes, void *arg)
   return 0;
 }
 
-
+#if 0
 static void jack_shutdown (void *arg)
 {
   jack_driver_t *this = (jack_driver_t *) arg;
   this->client = NULL;
 }
+#endif
 
 /*
  * Open the Jack audio device
@@ -295,7 +296,6 @@ static int jack_open_device (ao_driver_t *this_gen, char *jack_device,
 {
   jack_driver_t *this = (jack_driver_t *) this_gen;
   const char **matching_ports = NULL;
-  char *port_name = NULL;
   jack_client_t *client = this->client;
 
   int port_flags = JackPortIsInput;
@@ -686,10 +686,9 @@ static ao_driver_t *open_jack_plugin (audio_driver_class_t *class_gen,
   uint32_t rate;
   char *jack_device;
   const char **matching_ports = NULL;
-  const char **port_names;
 
   /* for usability reasons, keep this in sync with audio_oss_out.c */
-  static char *speaker_arrangement[] = {
+  static const char * const speaker_arrangement[] = {
     "Mono 1.0", "Stereo 2.0", "Headphones 2.0", "Stereo 2.1",
     "Surround 3.0", "Surround 4.0", "Surround 4.1", "Surround 5.0",
     "Surround 5.1", "Surround 6.0",
