@@ -68,6 +68,7 @@ typedef struct ff_video_class_s {
   int                     thread_count;
   int8_t                  skip_loop_filter_enum;
   int8_t                  choose_speed_over_accuracy;
+  uint8_t                 enable_dri;
 
   xine_t                 *xine;
 } ff_video_class_t;
@@ -92,7 +93,7 @@ struct ff_video_decoder_s {
   uint8_t           is_mpeg12:1;
   uint8_t           pp_available:1;
   uint8_t           yuv_init:1;
-  uint8_t           is_direct_rendering_disabled:1;
+  uint8_t           is_direct_rendering_disabled:1;  /* used only to avoid flooding log */
   uint8_t           cs_convert_init:1;
   uint8_t           assume_bad_field_picture:1;
 
@@ -127,13 +128,53 @@ struct ff_video_decoder_s {
 
   yuv_planes_t      yuv;
 
+#ifdef AVPaletteControl
   AVPaletteControl  palette_control;
+#endif
+
+  int               color_matrix, full2mpeg;
+  unsigned char     ytab[256], ctab[256];
 
 #ifdef LOG
   enum PixelFormat  debug_fmt;
 #endif
 };
 
+static void ff_check_colorspace (ff_video_decoder_t *this) {
+  int i, cm;
+
+#ifdef AVCODEC_HAS_COLORSPACE
+  cm = this->context->colorspace << 1;
+#else
+  cm = 0;
+#endif
+
+  /* ffmpeg bug: color_range not set by svq3 decoder */
+  i = this->context->pix_fmt;
+  if (cm && ((i == PIX_FMT_YUVJ420P) || (i == PIX_FMT_YUVJ444P)))
+    cm |= 1;
+#ifdef AVCODEC_HAS_COLORSPACE
+  if (this->context->color_range == AVCOL_RANGE_JPEG)
+    cm |= 1;
+#endif
+
+  /* report changes of colorspyce and/or color range */
+  if (cm != this->color_matrix) {
+    this->color_matrix = cm;
+    xprintf (this->stream->xine, XINE_VERBOSITY_LOG,
+      "ffmpeg_video_dec: color matrix #%d\n", cm >> 1);
+
+    this->full2mpeg = 0;
+    if (cm & 1) {
+      /* sigh. fall back to manual conversion */
+      this->full2mpeg = 1;
+      for (i = 0; i < 256; i++) {
+        this->ytab[i] = (219 * i + 127) / 255 + 16;
+        this->ctab[i] = 112 * (i - 128) / 127 + 128;
+      }
+    }
+  }
+}
 
 static void set_stream_info(ff_video_decoder_t *this) {
   _x_stream_info_set(this->stream, XINE_STREAM_INFO_VIDEO_WIDTH,  this->bih.biWidth);
@@ -149,6 +190,8 @@ static int get_buffer(AVCodecContext *context, AVFrame *av_frame){
   int width  = context->width;
   int height = context->height;
 
+  ff_check_colorspace (this);
+
   if (!this->bih.biWidth || !this->bih.biHeight) {
     this->bih.biWidth = width;
     this->bih.biHeight = height;
@@ -163,7 +206,8 @@ static int get_buffer(AVCodecContext *context, AVFrame *av_frame){
 
   avcodec_align_dimensions(context, &width, &height);
 
-  if( this->context->pix_fmt != PIX_FMT_YUV420P && this->context->pix_fmt != PIX_FMT_YUVJ420P ) {
+  if (this->full2mpeg || (this->context->pix_fmt != PIX_FMT_YUV420P &&
+    this->context->pix_fmt != PIX_FMT_YUVJ420P)) {
     if (!this->is_direct_rendering_disabled) {
       xprintf(this->stream->xine, XINE_VERBOSITY_LOG,
               _("ffmpeg_video_dec: unsupported frame format, DR1 disabled.\n"));
@@ -195,6 +239,8 @@ static int get_buffer(AVCodecContext *context, AVFrame *av_frame){
     }
   }
 
+  this->is_direct_rendering_disabled = 0;
+
   img = this->stream->video_out->get_frame (this->stream->video_out,
                                             width,
                                             height,
@@ -215,14 +261,16 @@ static int get_buffer(AVCodecContext *context, AVFrame *av_frame){
   /* We should really keep track of the ages of xine frames (see
    * avcodec_default_get_buffer in libavcodec/utils.c)
    * For the moment tell ffmpeg that every frame is new (age = bignumber) */
+#ifdef AVFRAMEAGE
   av_frame->age = 256*256*256*64;
+#endif
 
   av_frame->type= FF_BUFFER_TYPE_USER;
 
   /* take over pts for this frame to have it reordered */
   av_frame->reordered_opaque = context->reordered_opaque;
 
-  xine_list_push_back(this->dr1_frames, av_frame);
+  xine_list_push_back(this->dr1_frames, img);
 
   return 0;
 }
@@ -239,10 +287,11 @@ static void release_buffer(struct AVCodecContext *context, AVFrame *av_frame){
 
     xine_list_iterator_t it;
 
-    it = xine_list_find(this->dr1_frames, av_frame);
+    it = xine_list_find(this->dr1_frames, av_frame->opaque);
     assert(it);
-    if( it != NULL )
+    if( it != NULL ) {
       xine_list_remove(this->dr1_frames, it);
+    }
   } else {
     avcodec_default_release_buffer(context, av_frame);
   }
@@ -309,7 +358,7 @@ static void init_video_codec (ff_video_decoder_t *this, unsigned int codec_type)
 
   /* Some codecs (eg rv10) copy flags in init so it's necessary to set
    * this flag here in case we are going to use direct rendering */
-  if(this->codec->capabilities & CODEC_CAP_DR1 && this->codec->id != CODEC_ID_H264) {
+  if(this->codec->capabilities & CODEC_CAP_DR1 && this->class->enable_dri) {
     this->context->flags |= CODEC_FLAG_EMU_EDGE;
   }
 
@@ -320,6 +369,13 @@ static void init_video_codec (ff_video_decoder_t *this, unsigned int codec_type)
   if (this->class->choose_speed_over_accuracy)
     this->context->flags2 |= CODEC_FLAG2_FAST;
 
+#ifdef DEPRECATED_AVCODEC_THREAD_INIT
+  if (this->class->thread_count > 1) {
+    if (this->codec->id != CODEC_ID_SVQ3)
+      this->context->thread_count = this->class->thread_count;
+  }
+#endif
+
   pthread_mutex_lock(&ffmpeg_lock);
   if (avcodec_open (this->context, this->codec) < 0) {
     pthread_mutex_unlock(&ffmpeg_lock);
@@ -347,14 +403,13 @@ static void init_video_codec (ff_video_decoder_t *this, unsigned int codec_type)
     }
   }
 
+#ifndef DEPRECATED_AVCODEC_THREAD_INIT
   if (this->class->thread_count > 1) {
     if (this->codec->id != CODEC_ID_SVQ3
-#ifndef DEPRECATED_AVCODEC_THREAD_INIT
-	&& avcodec_thread_init(this->context, this->class->thread_count) != -1
-#endif
-	)
+	&& avcodec_thread_init(this->context, this->class->thread_count) != -1)
       this->context->thread_count = this->class->thread_count;
   }
+#endif
 
   this->context->skip_loop_filter = skip_loop_filter_enum_values[this->class->skip_loop_filter_enum];
 
@@ -383,7 +438,7 @@ static void init_video_codec (ff_video_decoder_t *this, unsigned int codec_type)
   /* enable direct rendering by default */
   this->output_format = XINE_IMGFMT_YV12;
 #ifdef ENABLE_DIRECT_RENDERING
-  if( this->codec->capabilities & CODEC_CAP_DR1 && this->codec->id != CODEC_ID_H264 ) {
+  if( this->codec->capabilities & CODEC_CAP_DR1 && this->class->enable_dri ) {
     this->context->get_buffer = get_buffer;
     this->context->release_buffer = release_buffer;
     xprintf(this->stream->xine, XINE_VERBOSITY_LOG,
@@ -413,9 +468,10 @@ static void init_video_codec (ff_video_decoder_t *this, unsigned int codec_type)
       break;
   }
 
+#ifdef AVCODEC_HAS_REORDERED_OPAQUE
   /* dont want initial AV_NOPTS_VALUE here */
   this->context->reordered_opaque = 0;
-
+#endif
 }
 
 static void choose_speed_over_accuracy_cb(void *user_data, xine_cfg_entry_t *entry) {
@@ -442,6 +498,12 @@ static void pp_quality_cb(void *user_data, xine_cfg_entry_t *entry) {
   class->pp_quality = entry->num_value;
 }
 
+static void dri_cb(void *user_data, xine_cfg_entry_t *entry) {
+  ff_video_class_t   *class = (ff_video_class_t *) user_data;
+
+  class->enable_dri = entry->num_value;
+}
+
 static void pp_change_quality (ff_video_decoder_t *this) {
   this->pp_quality = this->class->pp_quality;
 
@@ -542,6 +604,8 @@ static void ff_convert_frame(ff_video_decoder_t *this, vo_frame_t *img) {
     printf ("frame format == %08x\n", this->debug_fmt = this->context->pix_fmt);
 #endif
 
+  ff_check_colorspace (this);
+
   dy = img->base[0];
   du = img->base[1];
   dv = img->base[2];
@@ -772,54 +836,91 @@ static void ff_convert_frame(ff_video_decoder_t *this, vo_frame_t *img) {
 
   } else {
 
-    for (y = 0; y < this->bih.biHeight; y++) {
-      xine_fast_memcpy (dy, sy, img->width);
+    int subsamph = (this->context->pix_fmt == PIX_FMT_YUV444P)
+                || (this->context->pix_fmt == PIX_FMT_YUVJ444P);
+    int subsampv = (this->context->pix_fmt != PIX_FMT_YUV420P)
+                && (this->context->pix_fmt != PIX_FMT_YUVJ420P);
 
-      dy += img->pitches[0];
+    if (this->full2mpeg) {
 
-      sy += this->av_frame->linesize[0];
-    }
-
-    for (y = 0; y < this->bih.biHeight / 2; y++) {
-
-      if (this->context->pix_fmt != PIX_FMT_YUV444P) {
-
-        xine_fast_memcpy (du, su, img->width/2);
-        xine_fast_memcpy (dv, sv, img->width/2);
-
-      } else {
-
-        int x;
-        uint8_t *src;
-        uint8_t *dst;
-
-        /* subsample */
-
-        src = su; dst = du;
-        for (x=0; x<(img->width/2); x++) {
-          *dst = *src;
-          dst++;
-          src += 2;
-        }
-        src = sv; dst = dv;
-        for (x=0; x<(img->width/2); x++) {
-          *dst = *src;
-          dst++;
-          src += 2;
-        }
+      uint8_t *ytab = this->ytab;
+      uint8_t *ctab = this->ctab;
+      uint8_t *p, *q;
+      int x;
 
+      for (y = 0; y < this->bih.biHeight; y++) {
+        p = sy;
+        q = dy;
+        for (x = img->width; x > 0; x--) *q++ = ytab[*p++];
+        dy += img->pitches[0];
+        sy += this->av_frame->linesize[0];
       }
 
-      du += img->pitches[1];
-      dv += img->pitches[2];
-
-      if (this->context->pix_fmt != PIX_FMT_YUV420P) {
-        su += 2*this->av_frame->linesize[1];
-        sv += 2*this->av_frame->linesize[2];
-      } else {
-        su += this->av_frame->linesize[1];
-        sv += this->av_frame->linesize[2];
+      for (y = 0; y < this->bih.biHeight / 2; y++) {
+        if (!subsamph) {
+          p = su, q = du;
+          for (x = img->width / 2; x > 0; x--) *q++ = ctab[*p++];
+          p = sv, q = dv;
+          for (x = img->width / 2; x > 0; x--) *q++ = ctab[*p++];
+        } else {
+          p = su, q = du;
+          for (x = img->width / 2; x > 0; x--) {*q++ = ctab[*p]; p += 2;}
+          p = sv, q = dv;
+          for (x = img->width / 2; x > 0; x--) {*q++ = ctab[*p]; p += 2;}
+        }
+        du += img->pitches[1];
+        dv += img->pitches[2];
+        if (subsampv) {
+          su += 2 * this->av_frame->linesize[1];
+          sv += 2 * this->av_frame->linesize[2];
+        } else {
+          su += this->av_frame->linesize[1];
+          sv += this->av_frame->linesize[2];
+        }
       }
+
+    } else {
+
+      for (y = 0; y < this->bih.biHeight; y++) {
+        xine_fast_memcpy (dy, sy, img->width);
+        dy += img->pitches[0];
+        sy += this->av_frame->linesize[0];
+      }
+
+      for (y = 0; y < this->bih.biHeight / 2; y++) {
+        if (!subsamph) {
+          xine_fast_memcpy (du, su, img->width/2);
+          xine_fast_memcpy (dv, sv, img->width/2);
+        } else {
+          int x;
+          uint8_t *src;
+          uint8_t *dst;
+          src = su;
+          dst = du;
+          for (x = 0; x < (img->width / 2); x++) {
+            *dst = *src;
+            dst++;
+            src += 2;
+          }
+          src = sv;
+          dst = dv;
+          for (x = 0; x < (img->width / 2); x++) {
+            *dst = *src;
+            dst++;
+            src += 2;
+          }
+        }
+        du += img->pitches[1];
+        dv += img->pitches[2];
+        if (subsampv) {
+          su += 2*this->av_frame->linesize[1];
+          sv += 2*this->av_frame->linesize[2];
+        } else {
+          su += this->av_frame->linesize[1];
+          sv += this->av_frame->linesize[2];
+        }
+      }
+
     }
   }
 }
@@ -1023,7 +1124,9 @@ static void ff_handle_special_buffer (ff_video_decoder_t *this, buf_element_t *b
     memcpy(this->context->extradata, buf->decoder_info_ptr[2],
       buf->decoder_info[2]);
 
-  } else if (buf->decoder_info[1] == BUF_SPECIAL_PALETTE) {
+  }
+#ifdef AVPaletteControl
+  else if (buf->decoder_info[1] == BUF_SPECIAL_PALETTE) {
     unsigned int i;
 
     palette_entry_t *demuxer_palette;
@@ -1042,7 +1145,9 @@ static void ff_handle_special_buffer (ff_video_decoder_t *this, buf_element_t *b
     }
     decoder_palette->palette_changed = 1;
 
-  } else if (buf->decoder_info[1] == BUF_SPECIAL_RV_CHUNK_TABLE) {
+  }
+#endif
+  else if (buf->decoder_info[1] == BUF_SPECIAL_RV_CHUNK_TABLE) {
     int i;
 
     lprintf("BUF_SPECIAL_RV_CHUNK_TABLE\n");
@@ -1504,8 +1609,8 @@ static void ff_handle_buffer (ff_video_decoder_t *this, buf_element_t *buf) {
           img->duration = video_step_to_use;
 
         /* additionally crop away the extra pixels due to adjusting frame size above */
-        img->crop_right  = this->crop_right  + (img->width  - this->bih.biWidth);
-        img->crop_bottom = this->crop_bottom + (img->height - this->bih.biHeight);
+        img->crop_right  = img->width  - this->bih.biWidth;
+        img->crop_bottom = img->height - this->bih.biHeight;
 
         /* transfer some more frame settings for deinterlacing */
         img->progressive_frame = !this->av_frame->interlaced_frame;
@@ -1536,8 +1641,8 @@ static void ff_handle_buffer (ff_video_decoder_t *this, buf_element_t *buf) {
       img->duration  = video_step_to_use;
 
       /* additionally crop away the extra pixels due to adjusting frame size above */
-      img->crop_right  = ((this->bih.biWidth  <= 0) ? 0 : this->crop_right)  + (img->width  - this->bih.biWidth);
-      img->crop_bottom = ((this->bih.biHeight <= 0) ? 0 : this->crop_bottom) + (img->height - this->bih.biHeight);
+      img->crop_right  = this->bih.biWidth  <= 0 ? 0 : (img->width  - this->bih.biWidth);
+      img->crop_bottom = this->bih.biHeight <= 0 ? 0 : (img->height - this->bih.biHeight);
 
       img->bad_frame = 1;
       this->skipframes = img->draw(img, this->stream);
@@ -1617,7 +1722,6 @@ static void ff_reset (video_decoder_t *this_gen) {
   if(this->context && this->decoder_ok)
   {
     xine_list_iterator_t it;
-    AVFrame *av_frame;
 
     avcodec_flush_buffers(this->context);
 
@@ -1625,8 +1729,9 @@ static void ff_reset (video_decoder_t *this_gen) {
      * don't release their DR1 frames */
     while( (it = xine_list_front(this->dr1_frames)) != NULL )
     {
-      av_frame = (AVFrame *)xine_list_get_value(this->dr1_frames, it);
-      release_buffer(this->context, av_frame);
+      vo_frame_t *img = (vo_frame_t *)xine_list_get_value(this->dr1_frames, it);
+      if (img)
+        img->free(img);
     }
     xine_list_clear(this->dr1_frames);
   }
@@ -1687,7 +1792,6 @@ static void ff_dispose (video_decoder_t *this_gen) {
 
   if (this->decoder_ok) {
     xine_list_iterator_t it;
-    AVFrame *av_frame;
 
     pthread_mutex_lock(&ffmpeg_lock);
     avcodec_close (this->context);
@@ -1697,8 +1801,9 @@ static void ff_dispose (video_decoder_t *this_gen) {
      * don't release their DR1 frames */
     while( (it = xine_list_front(this->dr1_frames)) != NULL )
     {
-      av_frame = (AVFrame *)xine_list_get_value(this->dr1_frames, it);
-      release_buffer(this->context, av_frame);
+      vo_frame_t *img = (vo_frame_t *)xine_list_get_value(this->dr1_frames, it);
+      if (img)
+        img->free(img);
     }
 
     this->stream->video_out->close(this->stream->video_out, this->stream);
@@ -1758,7 +1863,9 @@ static video_decoder_t *ff_video_open_plugin (video_decoder_class_t *class_gen,
   this->av_frame          = avcodec_alloc_frame();
   this->context           = avcodec_alloc_context();
   this->context->opaque   = this;
+#ifdef AVPaletteControl
   this->context->palctrl  = NULL;
+#endif
 
   this->decoder_ok        = 0;
   this->decoder_init_mode = 1;
@@ -1839,6 +1946,12 @@ void *init_video_plugin (xine_t *xine, void *data) {
       "A change of this setting will take effect with playing the next stream."),
     10, choose_speed_over_accuracy_cb, this);
 
+  this->enable_dri = xine->config->register_bool(config, "video.processing.ffmpeg_direct_rendering", 1,
+    _("Enable direct rendering"),
+    _("Disable direct rendering if you are experiencing lock-ups with\n"
+      "streams with lot of reference frames."),
+    10, dri_cb, this);
+
   return this;
 }
 
