@@ -66,9 +66,9 @@
 #define LOG
 */
 
-#include "xine_internal.h"
-#include "xineutils.h"
-#include "input_plugin.h"
+#include <xine/xine_internal.h>
+#include <xine/xineutils.h>
+#include <xine/input_plugin.h>
 #include "net_buf_ctrl.h"
 
 #define NET_BS_LEN 2324
@@ -249,8 +249,9 @@ static int host_connect(const char *host, int port, xine_t *xine) {
 #define HIGH_WATER_MARK 100
 
 static off_t net_plugin_read (input_plugin_t *this_gen,
-			      char *buf, off_t len) {
+			      void *buf_gen, off_t len) {
   net_input_plugin_t *this = (net_input_plugin_t *) this_gen;
+  char *buf = (char *)buf_gen;
   off_t n, total;
 
   lprintf("reading %" PRIdMAX " bytes...\n", (intmax_t)len);
@@ -522,20 +523,6 @@ static input_plugin_t *net_class_get_instance (input_class_t *cls_gen, xine_stre
  *  net plugin class
  */
 
-static const char *net_class_get_description (input_class_t *this_gen) {
-	return _("net input plugin as shipped with xine");
-}
-
-static const char *net_class_get_identifier (input_class_t *this_gen) {
-  return "TCP";
-}
-
-static void net_class_dispose (input_class_t *this_gen) {
-  net_input_class_t  *this = (net_input_class_t *) this_gen;
-
-  free (this);
-}
-
 static void *init_class (xine_t *xine, void *data) {
 
   net_input_class_t  *this;
@@ -545,11 +532,11 @@ static void *init_class (xine_t *xine, void *data) {
   this->xine   = xine;
 
   this->input_class.get_instance      = net_class_get_instance;
-  this->input_class.get_description   = net_class_get_description;
-  this->input_class.get_identifier    = net_class_get_identifier;
+  this->input_class.description       = N_("net input plugin as shipped with xine");
+  this->input_class.identifier        = "TCP";
   this->input_class.get_dir           = NULL;
   this->input_class.get_autoplay_list = NULL;
-  this->input_class.dispose           = net_class_dispose;
+  this->input_class.dispose           = default_input_class_dispose;
   this->input_class.eject_media       = NULL;
 
   return this;
@@ -561,7 +548,7 @@ static void *init_class (xine_t *xine, void *data) {
 
 const plugin_info_t xine_plugin_info[] EXPORTED = {
   /* type, API, "name", version, special_info, init_function */
-  { PLUGIN_INPUT, 17, "tcp", XINE_VERSION_CODE, NULL, init_class },
+  { PLUGIN_INPUT, 18, "tcp", XINE_VERSION_CODE, NULL, init_class },
   { PLUGIN_NONE, 0, "", 0, NULL, NULL }
 };
 
