@@ -51,8 +51,8 @@
 /*
 #define LOG
 */
-#include "xine_internal.h"
-#include "xineutils.h"
+#include <xine/xine_internal.h>
+#include <xine/xineutils.h>
 
 #include "bswap.h"
 #include "http_helper.h"
@@ -445,7 +445,7 @@ static int interp_header (mmsh_t *this) {
   return 1;
 }
 
-static const char *const mmsh_proto_s[] = { "mms", "mmsh", NULL };
+static const char mmsh_proto_s[][8] = { "mms", "mmsh", "" };
 
 static int mmsh_valid_proto (char *proto) {
   int i = 0;
@@ -455,7 +455,7 @@ static int mmsh_valid_proto (char *proto) {
   if (!proto)
     return 0;
 
-  while(mmsh_proto_s[i]) {
+  while(*(mmsh_proto_s[i])) {
     if (!strcasecmp(proto, mmsh_proto_s[i])) {
       return 1;
     }
