@@ -126,10 +126,6 @@ static void nbc_set_speed_normal (nbc_t *this) {
   stream->xine->clock->set_option (stream->xine->clock, CLOCK_SCR_ADJUSTABLE, 1);
 }
 
-void nbc_check_buffers (nbc_t *this) {
-  /* Deprecated */
-}
-
 static void dvbspeed_init (nbc_t *this) {
   const char *mrl;
   if (this->stream && this->stream->input_plugin) {
@@ -800,22 +796,3 @@ void nbc_close (nbc_t *this) {
   free (this);
   xprintf(xine, XINE_VERBOSITY_DEBUG, "\nnet_buf_ctrl: nbc_close: done\n");
 }
-
-
-void nbc_set_high_water_mark(nbc_t *this, int value) {
-/*
-  Deprecated
-  this->high_water_mark = value;
-*/
-  xprintf(this->stream->xine, XINE_VERBOSITY_DEBUG,
-	  "\nnet_buf_ctrl: this method is deprecated, please fix the input plugin\n");
-}
-
-void nbc_set_low_water_mark(nbc_t *this, int value) {
-/*
-  Deprecated
-  this->low_water_mark = value;
-*/
-  xprintf(this->stream->xine, XINE_VERBOSITY_DEBUG,
-	  "\nnet_buf_ctrl: this method is deprecated, please fix the input plugin\n");
-}
