@@ -38,9 +38,9 @@
 */
 
 #include "bswap.h"
-#include "xine_internal.h"
-#include "audio_out.h"
-#include "buffer.h"
+#include <xine/xine_internal.h>
+#include <xine/audio_out.h>
+#include <xine/buffer.h>
 
 #include "qtx/qtxsdk/components.h"
 #include "wine/win32.h"
@@ -569,19 +569,6 @@ static audio_decoder_t *qta_open_plugin (audio_decoder_class_t *class_gen,
 /*
  * qta plugin class
  */
-
-static char *qta_get_identifier (audio_decoder_class_t *this) {
-  return "qta";
-}
-
-static char *qta_get_description (audio_decoder_class_t *this) {
-  return "quicktime audio decoder plugin";
-}
-
-static void qta_dispose_class (audio_decoder_class_t *this) {
-  free (this);
-}
-
 static void *qta_init_class (xine_t *xine, void *data) {
 
   qta_class_t     *this;
@@ -595,14 +582,14 @@ static void *qta_init_class (xine_t *xine, void *data) {
   this = (qta_class_t *) calloc(1, sizeof(qta_class_t));
 
   this->decoder_class.open_plugin     = qta_open_plugin;
-  this->decoder_class.get_identifier  = qta_get_identifier;
-  this->decoder_class.get_description = qta_get_description;
-  this->decoder_class.dispose         = qta_dispose_class;
+  this->decoder_class.identifier      = "qta";
+  this->decoder_class.description     = N_("quicktime audio decoder plugin");
+  this->decoder_class.dispose         = default_audio_decoder_class_dispose;
 
   return this;
 }
 
-static uint32_t audio_types[] = {
+static const uint32_t audio_types[] = {
   BUF_AUDIO_QDESIGN1,
   BUF_AUDIO_QDESIGN2,
   BUF_AUDIO_QCLP,
@@ -1081,18 +1068,6 @@ static video_decoder_t *qtv_open_plugin (video_decoder_class_t *class_gen,
  * qtv plugin class
  */
 
-static char *qtv_get_identifier (video_decoder_class_t *this) {
-  return "qtvdec";
-}
-
-static char *qtv_get_description (video_decoder_class_t *this) {
-  return "quicktime binary-only codec based video decoder plugin";
-}
-
-static void qtv_dispose_class (video_decoder_class_t *this) {
-  free (this);
-}
-
 /*
  * some fake functions to make qt codecs happy
  */
@@ -1119,9 +1094,9 @@ static void *qtv_init_class (xine_t *xine, void *data) {
   this = (qtv_class_t *) calloc(1, sizeof(qtv_class_t));
 
   this->decoder_class.open_plugin     = qtv_open_plugin;
-  this->decoder_class.get_identifier  = qtv_get_identifier;
-  this->decoder_class.get_description = qtv_get_description;
-  this->decoder_class.dispose         = qtv_dispose_class;
+  this->decoder_class.identifier      = "qtvdec";
+  this->decoder_class.description     = N_("quicktime binary-only codec based video decoder plugin");
+  this->decoder_class.dispose         = default_video_decoder_class_dispose;
 
   return this;
 }
@@ -1130,7 +1105,7 @@ static void *qtv_init_class (xine_t *xine, void *data) {
  * exported plugin catalog entry
  */
 
-static uint32_t qtv_supported_types[] = { BUF_VIDEO_SORENSON_V3, 0 };
+static const uint32_t qtv_supported_types[] = { BUF_VIDEO_SORENSON_V3, 0 };
 
 static const decoder_info_t qtv_dec_info = {
   qtv_supported_types,     /* supported types */
@@ -1139,7 +1114,7 @@ static const decoder_info_t qtv_dec_info = {
 
 const plugin_info_t xine_plugin_info[] EXPORTED = {
   /* type, API, "name", version, special_info, init_function */
-  { PLUGIN_VIDEO_DECODER | PLUGIN_MUST_PRELOAD, 18, "qtv", XINE_VERSION_CODE, &qtv_dec_info, qtv_init_class },
-  { PLUGIN_AUDIO_DECODER | PLUGIN_MUST_PRELOAD, 15, "qta", XINE_VERSION_CODE, &qta_dec_info, qta_init_class },
+  { PLUGIN_VIDEO_DECODER | PLUGIN_MUST_PRELOAD, 19, "qtv", XINE_VERSION_CODE, &qtv_dec_info, qtv_init_class },
+  { PLUGIN_AUDIO_DECODER | PLUGIN_MUST_PRELOAD, 16, "qta", XINE_VERSION_CODE, &qta_dec_info, qta_init_class },
   { PLUGIN_NONE, 0, "", 0, NULL, NULL }
 };
