@@ -20,7 +20,7 @@
  * This file contains plugin entries for several visualization post plugins.
  */
 
-#include "xine_internal.h"
+#include <xine/xine_internal.h>
 
 void *oscope_init_plugin(xine_t *xine, void *data);
 void *fftscope_init_plugin(xine_t *xine, void *data);
