@@ -25,19 +25,21 @@
  * - Implement support for teletext based subtitles
  */
 
-#include "pthread.h"
+#include <pthread.h>
 #include <errno.h>
+
+/*#define LOG*/
+#define LOG_MODULE "spudvb"
+
 #include <xine/xine_internal.h>
 #include <xine/spu.h>
 #include <xine/osd.h>
+
 #define MAX_REGIONS 7
 
 #define SPU_MAX_WIDTH 1920
 #define SPU_MAX_HEIGHT 1080
 
-/*#define LOG*/
-#define LOG_MODULE "spudvb"
-
 typedef struct {
   int			x, y;
   unsigned char	is_visible;
@@ -181,7 +183,6 @@ static void update_region (dvb_spu_decoder_t * this, int region_id, int region_w
 
   dvbsub_func_t *dvbsub = this->dvbsub;
   region_t *reg = &dvbsub->regions[region_id];
-  page_t *page = &dvbsub->page;
 
   /* reject invalid sizes and set some limits ! */
   if ( region_width<=0 || region_height<=0 || region_width>SPU_MAX_WIDTH || region_height>SPU_MAX_HEIGHT ) {
@@ -730,7 +731,6 @@ static void process_object_data_segment (dvb_spu_decoder_t * this)
 
   dvbsub_func_t *dvbsub = this->dvbsub;
 
-  int j;
   int old_i;
   int r;
 
@@ -901,7 +901,6 @@ static void draw_subtitles (dvb_spu_decoder_t * this)
   for ( r=0; r<MAX_REGIONS; r++ ) {
     lprintf("region=%d, visible=%d, osd=%d, empty=%d\n", r, this->dvbsub->page.regions[r].is_visible, this->dvbsub->regions[r].osd?1:0, this->dvbsub->regions[r].empty );
     if ( this->dvbsub->page.regions[r].is_visible && this->dvbsub->regions[r].osd && !this->dvbsub->regions[r].empty ) {
-      this->stream->osd_renderer->set_extent(this->dvbsub->regions[r].osd, SPU_MAX_WIDTH, SPU_MAX_HEIGHT);
       this->stream->osd_renderer->set_position( this->dvbsub->regions[r].osd, this->dvbsub->page.regions[r].x, this->dvbsub->page.regions[r].y );
       this->stream->osd_renderer->show( this->dvbsub->regions[r].osd, this->vpts );
       lprintf("show region = %d\n",r);
@@ -926,7 +925,6 @@ static void spudec_decode_data (spu_decoder_t * this_gen, buf_element_t * buf)
       int new_i;
       int data_identifier, subtitle_stream_id;
       int segment_length, segment_type;
-      int PES_header_data_length;
       int PES_packet_length;
       int i;
 
