@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2003, 2007 the xine project
+ * Copyright (C) 2000-2003, 2007-2008 the xine project
  *
  * This file is part of xine, a free video player.
  *
@@ -37,7 +37,7 @@
 #include <math.h>
 
 #include "xine.h"
-#include "video_out.h"
+#include <xine/video_out.h>
 
 #include <errno.h>
 
@@ -50,16 +50,22 @@
 #include <pthread.h>
 #include <netinet/in.h>
 
+#ifdef HAVE_FFMPEG_AVUTIL_H
+#  include <mem.h>
+#else
+#  include <libavutil/mem.h>
+#endif
+
 #define LOG_MODULE "video_out_xcbshm"
 #define LOG_VERBOSE
 /*
 #define LOG
 */
 
-#include "xine_internal.h"
+#include <xine/xine_internal.h>
 #include "yuv2rgb.h"
-#include "xineutils.h"
-#include "vo_scale.h"
+#include <xine/xineutils.h>
+#include <xine/vo_scale.h>
 #include "xcbosd.h"
 
 typedef struct {
@@ -76,8 +82,6 @@ typedef struct {
   int                bytes_per_line;
   xcb_shm_seg_t      shmseg;
 
-  uint8_t           *chunk[3]; /* mem alloc by xmalloc_aligned           */
-
   yuv2rgb_t         *yuv2rgb; /* yuv2rgb converter set up for this frame */
   uint8_t           *rgb_dst;
 
@@ -147,8 +151,9 @@ static void create_ximage(xshm_driver_t *this, xshm_frame_t *frame, int width, i
 
     if (shmid < 0) {
       xprintf(this->xine, XINE_VERBOSITY_LOG,
-	      _("video_out_xcbshm: %s: allocating image\n"
-		"video_out_xcbshm: => not using MIT Shared Memory extension.\n"), strerror(errno));
+	      _("%s: %s: allocating image\n"), LOG_MODULE, strerror(errno));
+      xprintf(this->xine, XINE_VERBOSITY_LOG,
+	      _("%s: => not using MIT Shared Memory extension.\n"), LOG_MODULE);
       goto shm_fail1;
     }
 
@@ -156,8 +161,9 @@ static void create_ximage(xshm_driver_t *this, xshm_frame_t *frame, int width, i
 
     if (frame->image == ((void *) -1)) {
       xprintf(this->xine, XINE_VERBOSITY_LOG,
-	      _("video_out_xcbshm: shared memory error (address error) when allocating image \n"
-		"video_out_xcbshm: => not using MIT Shared Memory extension.\n"));
+	      _("%s: shared memory error (address error) when allocating image \n"), LOG_MODULE);
+      xprintf(this->xine, XINE_VERBOSITY_LOG,
+	      _("%s: => not using MIT Shared Memory extension.\n"), LOG_MODULE);
       goto shm_fail2;
     }
 
@@ -167,8 +173,9 @@ static void create_ximage(xshm_driver_t *this, xshm_frame_t *frame, int width, i
 
     if (generic_error != NULL) {
       xprintf(this->xine, XINE_VERBOSITY_LOG,
-	      _("video_out_xcbshm: x11 error during shared memory XImage creation\n"
-		"video_out_xcbshm: => not using MIT Shared Memory extension.\n"));
+	      _("%s: x11 error during shared memory XImage creation\n"), LOG_MODULE);
+      xprintf(this->xine, XINE_VERBOSITY_LOG,
+	      _("%s: => not using MIT Shared Memory extension.\n"), LOG_MODULE);
       free(generic_error);
       goto shm_fail3;
     }
@@ -218,7 +225,7 @@ static void dispose_ximage(xshm_driver_t *this, xshm_frame_t *frame)
 
 static uint32_t xshm_get_capabilities (vo_driver_t *this_gen) {
   xshm_driver_t *this = (xshm_driver_t *) this_gen;
-  uint32_t capabilities = VO_CAP_YV12 | VO_CAP_YUY2;
+  uint32_t capabilities = VO_CAP_YV12 | VO_CAP_YUY2 | VO_CAP_BRIGHTNESS | VO_CAP_CONTRAST | VO_CAP_SATURATION;
 
   if( this->xoverlay )
     capabilities |= VO_CAP_UNSCALED_OVERLAY;
@@ -284,9 +291,9 @@ static void xshm_frame_dispose (vo_frame_t *vo_img) {
 
   frame->yuv2rgb->dispose (frame->yuv2rgb);
 
-  free (frame->chunk[0]);
-  free (frame->chunk[1]);
-  free (frame->chunk[2]);
+  av_free (frame->vo_frame.base[0]);
+  av_free (frame->vo_frame.base[1]);
+  av_free (frame->vo_frame.base[2]);
   free (frame);
 }
 
@@ -434,18 +441,9 @@ static void xshm_update_frame_format (vo_driver_t *this_gen,
 
       dispose_ximage(this, frame);
 
-      if (frame->chunk[0]){
-	free (frame->chunk[0]);
-	frame->chunk[0] = NULL;
-      }
-      if (frame->chunk[1]) {
-	free (frame->chunk[1]);
-	frame->chunk[1] = NULL;
-      }
-      if (frame->chunk[2]) {
-	free (frame->chunk[2]);
-	frame->chunk[2] = NULL;
-      }
+      av_freep(&frame->vo_frame.base[0]);
+      av_freep(&frame->vo_frame.base[1]);
+      av_freep(&frame->vo_frame.base[2]);
     }
 
     create_ximage(this, frame, frame->sc.output_width, frame->sc.output_height);
@@ -456,14 +454,12 @@ static void xshm_update_frame_format (vo_driver_t *this_gen,
       frame->vo_frame.pitches[0] = 8*((width + 7) / 8);
       frame->vo_frame.pitches[1] = 8*((width + 15) / 16);
       frame->vo_frame.pitches[2] = 8*((width + 15) / 16);
-      frame->vo_frame.base[0] = xine_xmalloc_aligned (16, frame->vo_frame.pitches[0] * height,  (void **) &frame->chunk[0]);
-      frame->vo_frame.base[1] = xine_xmalloc_aligned (16, frame->vo_frame.pitches[1] * ((height+1)/2), (void **) &frame->chunk[1]);
-      frame->vo_frame.base[2] = xine_xmalloc_aligned (16, frame->vo_frame.pitches[2] * ((height+1)/2), (void **) &frame->chunk[2]);
+      frame->vo_frame.base[0] = av_mallocz(frame->vo_frame.pitches[0] * height);
+      frame->vo_frame.base[1] = av_mallocz(frame->vo_frame.pitches[1] * ((height+1)/2));
+      frame->vo_frame.base[2] = av_mallocz(frame->vo_frame.pitches[2] * ((height+1)/2));
     } else {
       frame->vo_frame.pitches[0] = 8*((width + 3) / 4);
-      frame->vo_frame.base[0] = xine_xmalloc_aligned (16, frame->vo_frame.pitches[0] * height, (void **) &frame->chunk[0]);
-      frame->chunk[1] = NULL;
-      frame->chunk[2] = NULL;
+      frame->vo_frame.base[0] = av_mallocz(frame->vo_frame.pitches[0] * height);
     }
 
     lprintf ("stripe out_ht=%i, deliv_ht=%i\n",
@@ -737,7 +733,7 @@ static int xshm_get_property (vo_driver_t *this_gen, int property) {
     return this->cur_frame->sc.output_yoffset;
   default:
     xprintf(this->xine, XINE_VERBOSITY_DEBUG,
-	    "video_out_xcbshm: tried to get unsupported property %d\n", property);
+	    LOG_MODULE ": tried to get unsupported property %d\n", property);
   }
 
   return 0;
@@ -747,47 +743,45 @@ static int xshm_set_property (vo_driver_t *this_gen,
 			      int property, int value) {
   xshm_driver_t *this = (xshm_driver_t *) this_gen;
 
-  if ( property == VO_PROP_ASPECT_RATIO) {
-
+  switch (property) {
+  case VO_PROP_ASPECT_RATIO:
     if (value>=XINE_VO_ASPECT_NUM_RATIOS)
       value = XINE_VO_ASPECT_AUTO;
     this->sc.user_ratio = value;
     xprintf(this->xine, XINE_VERBOSITY_DEBUG,
-	    "video_out_xcbshm: aspect ratio changed to %s\n", _x_vo_scale_aspect_ratio_name(value));
-
-  } else if (property == VO_PROP_BRIGHTNESS) {
+	    LOG_MODULE ": aspect ratio changed to %s\n", _x_vo_scale_aspect_ratio_name_table[value]);
+    break;
 
+  case VO_PROP_BRIGHTNESS:
     this->yuv2rgb_brightness = value;
     this->yuv2rgb_factory->set_csc_levels (this->yuv2rgb_factory,
 					   this->yuv2rgb_brightness,
 					   this->yuv2rgb_contrast,
 					   this->yuv2rgb_saturation);
-
     this->sc.force_redraw = 1;
+    break;
 
-  } else if (property == VO_PROP_CONTRAST) {
-
+  case VO_PROP_CONTRAST:
     this->yuv2rgb_contrast = value;
     this->yuv2rgb_factory->set_csc_levels (this->yuv2rgb_factory,
 					   this->yuv2rgb_brightness,
 					   this->yuv2rgb_contrast,
 					   this->yuv2rgb_saturation);
-
     this->sc.force_redraw = 1;
+    break;
 
-  } else if (property == VO_PROP_SATURATION) {
-
+  case VO_PROP_SATURATION:
     this->yuv2rgb_saturation = value;
     this->yuv2rgb_factory->set_csc_levels (this->yuv2rgb_factory,
 					   this->yuv2rgb_brightness,
 					   this->yuv2rgb_contrast,
 					   this->yuv2rgb_saturation);
-
     this->sc.force_redraw = 1;
+    break;
 
-  } else {
+  default:
     xprintf (this->xine, XINE_VERBOSITY_DEBUG,
-	     "video_out_xcbshm: tried to set unsupported property %d\n", property);
+	     LOG_MODULE ": tried to set unsupported property %d\n", property);
   }
 
   return value;
@@ -963,7 +957,7 @@ static int ImlibPaletteLUTGet(xshm_driver_t *this) {
     char *retval = xcb_get_property_value(prop_reply);
 
     j = 1 + retval[0]*4;
-    this->yuv2rgb_cmap = malloc(sizeof(uint8_t) * 32 * 32 * 32);
+    this->yuv2rgb_cmap = xine_xcalloc(sizeof(uint8_t), 32 * 32 * 32);
     for (i = 0; i < 32 * 32 * 32 && j < num_ret; i++)
       this->yuv2rgb_cmap[i] = retval[1+4*retval[j++]+3];
 
@@ -975,8 +969,8 @@ static int ImlibPaletteLUTGet(xshm_driver_t *this) {
   return 0;
 }
 
-
-static char *visual_class_name(xcb_visualtype_t *visual) {
+/* TODO replace this with a string table. */
+static const char *visual_class_name(xcb_visualtype_t *visual) {
 
   switch (visual->_class) {
   case XCB_VISUAL_CLASS_STATIC_GRAY:
@@ -1111,7 +1105,7 @@ static vo_driver_t *xshm_open_plugin(video_driver_class_t *class_gen, const void
   }
   else {
     xprintf(this->xine, XINE_VERBOSITY_LOG,
-	    _("video_out_xcbshm: MIT shared memory extension not present on display.\n"));
+	    _("%s: MIT shared memory extension not present on display.\n"), LOG_MODULE);
     this->use_shm = 0;
   }
 
@@ -1149,8 +1143,8 @@ static vo_driver_t *xshm_open_plugin(video_driver_class_t *class_gen, const void
   swapped = cpu_byte_order != image_byte_order;
 
   xprintf(this->xine, XINE_VERBOSITY_DEBUG,
-	  "video_out_xcbshm: video mode depth is %d (%d bpp), %s, %sswapped,\n"
-	  "\tred: %08x, green: %08x, blue: %08x\n",
+	  LOG_MODULE ": video mode depth is %d (%d bpp), %s, %sswapped,\n"
+	  LOG_MODULE ": red: %08x, green: %08x, blue: %08x\n",
 	  this->depth, this->bpp,
 	  visual_class_name(visualtype),
 	  swapped ? "" : "not ",
@@ -1210,7 +1204,7 @@ static vo_driver_t *xshm_open_plugin(video_driver_class_t *class_gen, const void
 
   if (!mode) {
     xprintf (this->xine, XINE_VERBOSITY_LOG,
-	     _("video_out_xcbshm: your video mode was not recognized, sorry :-(\n"));
+	     _("%s: your video mode was not recognized, sorry :-(\n"), LOG_MODULE);
     return NULL;
   }
 
@@ -1234,28 +1228,13 @@ static vo_driver_t *xshm_open_plugin(video_driver_class_t *class_gen, const void
 /*
  * class functions
  */
-
-static char* xshm_get_identifier (video_driver_class_t *this_gen) {
-  return "XShm";
-}
-
-static char* xshm_get_description (video_driver_class_t *this_gen) {
-  return _("xine video output plugin using the MIT X shared memory extension");
-}
-
-static void xshm_dispose_class (video_driver_class_t *this_gen) {
-  xshm_class_t         *this = (xshm_class_t *) this_gen;
-
-  free (this);
-}
-
 static void *xshm_init_class (xine_t *xine, void *visual_gen) {
   xshm_class_t	       *this = (xshm_class_t *) calloc(1, sizeof(xshm_class_t));
 
   this->driver_class.open_plugin     = xshm_open_plugin;
-  this->driver_class.get_identifier  = xshm_get_identifier;
-  this->driver_class.get_description = xshm_get_description;
-  this->driver_class.dispose         = xshm_dispose_class;
+  this->driver_class.identifier      = "XShm";
+  this->driver_class.description     = N_("xine video output plugin using the MIT X shared memory extension");
+  this->driver_class.dispose         = default_video_driver_class_dispose;
   this->config                       = xine->config;
   this->xine                         = xine;
 
@@ -1275,6 +1254,6 @@ static const vo_info_t vo_info_xshm = {
 
 const plugin_info_t xine_plugin_info[] EXPORTED = {
   /* type, API, "name", version, special_info, init_function */
-  { PLUGIN_VIDEO_OUT, 21, "xshm", XINE_VERSION_CODE, &vo_info_xshm, xshm_init_class },
+  { PLUGIN_VIDEO_OUT, 22, "xshm", XINE_VERSION_CODE, &vo_info_xshm, xshm_init_class },
   { PLUGIN_NONE, 0, "", 0, NULL, NULL }
 };
