@@ -280,6 +280,8 @@ typedef struct {
 
   sXYData         eq_data_history[EQ_BANDS][EQ_CHANNELS];
 
+  int             last_gap;
+
 } aos_t;
 
 struct audio_fifo_s {
@@ -1166,6 +1168,7 @@ static void *ao_loop (void *this_gen) {
      * calculate gap:
      */
     gap = in_buf->vpts - hw_vpts;
+    this->last_gap = gap;
     lprintf ("hw_vpts : %" PRId64 " buffer_vpts : %" PRId64 " gap : %" PRId64 "\n",
              hw_vpts, in_buf->vpts, gap);
 
@@ -1828,6 +1831,10 @@ static int ao_get_property (xine_audio_port_t *this_gen, int property) {
     ret = this->current_speed;
     break;
 
+  case AO_PROP_DRIVER_DELAY:
+    ret = this->last_gap;
+    break;
+
   default:
     inc_num_driver_actions(this);
     pthread_mutex_lock( &this->driver_lock );
@@ -2300,7 +2307,7 @@ xine_audio_port_t *_x_ao_new_port (xine_t *xine, ao_driver_t *driver,
     this->audio_loop_running = 1;
 
     pthread_attr_init(&pth_attrs);
-#ifdef _POSIX_THREAD_PRIORITY_SCHEDULING
+#if defined(_POSIX_THREAD_PRIORITY_SCHEDULING) && (_POSIX_THREAD_PRIORITY_SCHEDULING > 0)
     pthread_attr_setscope(&pth_attrs, PTHREAD_SCOPE_SYSTEM);
 #endif
 
