@@ -26,7 +26,7 @@
 
 #define XINE_ENGINE_INTERNAL
 
-#include "xine_internal.h"
+#include <xine/xine_internal.h>
 
 xine_event_t *xine_event_get  (xine_event_queue_t *queue) {
 
