@@ -83,6 +83,10 @@
 
 #include "xine_private.h"
 
+/* FIXME-ABI Global variable. Done this way for ABI & API reasons... */
+int _x_flags = 0;
+
+
 static void mutex_cleanup (void *mutex) {
   pthread_mutex_unlock ((pthread_mutex_t *) mutex);
 }
@@ -1742,6 +1746,12 @@ static void config_save_cb (void *this_gen, xine_cfg_entry_t *entry) {
   this->save_path = entry->str_value;
 }
 
+void xine_set_flags (xine_t *this, int flags)
+{
+  this = this; /* FIXME-ABI: one day, these will be in xine_t...? */
+  _x_flags = flags;
+}
+
 void xine_init (xine_t *this) {
   static const char *const demux_strategies[] = {"default", "reverse", "content",
 						 "extension", NULL};
@@ -2026,7 +2036,7 @@ static int _x_get_current_frame_data (xine_stream_t *stream,
 				      int flags, int img_size_unknown) {
 
   vo_frame_t *frame;
-  size_t required_size;
+  size_t required_size = 0;
 
   stream->xine->port_ticket->acquire(stream->xine->port_ticket, 0);
   frame = stream->video_out->get_last_frame (stream->video_out);
