@@ -1,4 +1,4 @@
-;/*
+/*
  * Copyright (C) 2001-2004 the xine project
  *
  * This file is part of xine, a free video player.
@@ -53,6 +53,7 @@
 */
 
 #include <xine/xine_internal.h>
+#include "../xine-engine/xine_private.h"
 
 void *(* xine_fast_memcpy)(void *to, const void *from, size_t len);
 
